==> drd-8.x-3.5.tar.gz: drd/src/Entity/Form/CoreUpdateLog.php <==
<?php

namespace Drupal\drd\Entity\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Entity\CoreInterface;

/**
 * Provides a form for reviewing Core update logs.
 *
 * @ingroup drd
 */
class CoreUpdateLog extends FormBase {

  /** @var CoreInterface */
  protected $core;

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'drd_core_updatelog';
  }

  /**
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, CoreInterface $drd_core = NULL, $timestamp = 0) {
    $this->core = $drd_core;
    $logList = $this->core->getUpdateLogList();
    if (empty($logList)) {
      $form['info'] = [
        '#markup' => $this->t('No update logs available'),
      ];
      return $form;
    }

    $current = FALSE;
    $select = [];
    foreach ($logList as $item) {
      $select[$item['timestamp']] = \Drupal::service('date.formatter')->format($item['timestamp']);
      if ($item['timestamp'] == $timestamp) {
        $current = $item;
      }
    }
    if (empty($current)) {
      // Default to latest item
      $current = $item;
    }

    $form['select'] = [
      '#type' => 'select',
      '#options' => $select,
      '#default_value' => $current['timestamp'],
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Select'),
    ];
    $form['log'] = [
      '#type' => 'textarea',
      '#default_value' => $this->core->getUpdateLog($current['timestamp']),
      '#rows' => 30,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect('entity.drd_core.updatelog', [
      'drd_core' => $this->core->id(),
      'timestamp' => $form_state->getValue('select'),
    ]);
  }

}

==> drd-8.x-3.10.tar.gz: drd/src/Entity/Form/CoreUpdateLog.php <==
<?php

namespace Drupal\drd\Entity\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for reviewing Core update logs.
 *
 * @ingroup drd
 */
class CoreUpdateLog extends FormBase {

  /** @var \Drupal\drd\Entity\CoreInterface */
  protected $core;

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'drd_core_updatelog';
  }

  /**
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state, $drd_core = NULL, $timestamp = 0) {
    $this->core = $drd_core;
    $logList = $this->core->getUpdateLogList();
    if (empty($logList)) {
      $form['info'] = [
        '#markup' => $this->t('No update logs available'),
      ];
      return $form;
    }

    $current = FALSE;
    $select = [];
    foreach ($logList as $item) {
      $select[$item['timestamp']] = \Drupal::service('date.formatter')->format($item['timestamp']);
      if ($item['timestamp'] == $timestamp) {
        $current = $item;
      }
    }
    if (empty($current)) {
      // Default to latest item
      $current = $item;
    }

    $form['select'] = [
      '#type' => 'select',
      '#options' => $select,
      '#default_value' => $current['timestamp'],
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Select'),
    ];
    $form['log'] = [
      '#type' => 'textarea',
      '#default_value' => $this->core->getUpdateLog($current['timestamp']),
      '#rows' => 30,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect('entity.drd_core.updatelog', [
      'drd_core' => $this->core->id(),
      'timestamp' => $form_state->getValue('select'),
    ]);
  }

}
